@@ -51,7 +51,7 @@ class GetMediaShowItemView(BrowserView):
         """
         item = self.context
         
-        if(self.isVideo(item)):
+        if(self.isVideo(item) or item.portal_type == 'Image'):
             return item.absolute_url()
         
         if item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
@@ -139,6 +139,9 @@ class MediaShowListingView(BrowserView):
             
         if item.portal_type == 'Link' and item.remoteUrl.find("youtube.com") > -1:
             return item.remoteUrl
+        
+        if item.portal_type == 'Image':
+            return item.absolute_url()
             
         catalog = getToolByName(self.context, 'portal_catalog')
         plone_utils = getToolByName(self.context, 'plone_utils')
